summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_object.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering/render_object.h')
-rw-r--r--khtml/rendering/render_object.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/khtml/rendering/render_object.h b/khtml/rendering/render_object.h
index e403601d3..f7f772387 100644
--- a/khtml/rendering/render_object.h
+++ b/khtml/rendering/render_object.h
@@ -441,7 +441,7 @@ public:
void layoutIfNeeded() { if (needsLayout()) layout(); }
// used for element state updates that can not be fixed with a
// tqrepaint and do not need a relayout
virtual void updateFromElement() {}
// Called immediately after render-object is inserted
@@ -681,8 +681,8 @@ public:
// Used by collapsed border tables.
virtual void collectBorders(TQValueList<CollapsedBorderValue>& borderStyles);
- // force a complete tqrepaint
- virtual void tqrepaint(Priority p = NormalPriority) { if(m_parent) m_parent->tqrepaint(p); }
+ // force a complete repaint
+ virtual void repaint(Priority p = NormalPriority) { if(m_parent) m_parent->repaint(p); }
virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
virtual unsigned int length() const { return 1; }
@@ -747,7 +747,7 @@ public:
virtual int leftmostPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
virtual int highestPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
- // recursively tqinvalidate current layout
+ // recursively invalidate current layout
// unused: void invalidateLayout();
virtual void calcVerticalMargins() {}
@@ -441,7 +441,7 @@ public:
void layoutIfNeeded() { if (needsLayout()) layout(); }
// used for element state updates that can not be fixed with a
- // tqrepaint and do not need a relayout
+ // repaint and do not need a relayout
virtual void updateFromElement() {}
// Called immediately after render-object is inserted